VerifyArgs

Enum VerifyArgs 

pub enum VerifyArgs {
    Files {
        before: String,
        after: PathBuf,
    },
    RunId {
        run_id: String,
        state_dir: PathBuf,
    },
}

Variants



Files

before is a file path, or a git revision whose copy of after is compared.

Fields

before: String
after: PathBuf


RunId

Compare every file a comments apply run modified against its backup.

Fields

run_id: String
state_dir: PathBuf