Core AST refactoring engine for rs-hack.
Parses Rust source into a syn AST, applies refactoring operations (add/remove/rename/update), and emits modified code via surgical edits or prettyplease reformatting.
Core AST refactoring engine for rs-hack.
Parses Rust source into a syn AST, applies refactoring operations (add/remove/rename/update), and emits modified code via surgical edits or prettyplease reformatting.