Module path_resolver

Module path_resolver 

Path resolution for safely matching qualified paths in Rust code. Tracks use statements and validates whether a path refers to a specific target.

Structs

PathResolver
Tracks use statements and validates whether paths refer to a specific target.