pub enum VerifyArgs {
Files {
before: String,
after: PathBuf,
},
RunId {
run_id: String,
state_dir: PathBuf,
},
}Variants
Files
before is a file path, or a git revision whose copy of after is compared.
RunId
Compare every file a comments apply run modified against its backup.