pub fn print_summary_diff(
path: &Path,
original: &str,
modified: &str,
) -> DiffStatsExpand description
Print a summary of changes (only changed lines with minimal context)
This shows a more focused view than a full unified diff, displaying only the lines that changed with their line numbers.
Arguments
path- The file pathoriginal- The original file contentmodified- The modified file content
Returns statistics about the diff.