RustEditor

Struct RustEditor 

pub struct RustEditor { /* private fields */ }

Implementations

Source

impl RustEditor

pub fn new(content: &str) -> Result<Self>

pub fn apply_operation(&mut self, op: &Operation) -> Result<ModificationResult>

pub fn to_string(&self) -> String

pub fn find_node( &self, node_type: &str, name: &str, ) -> Result<Vec<NodeLocation>>

Source

impl RustEditor

pub fn add_doc_comment_surgical( &mut self, target_type: &str, target_name: &str, doc_text: &str, style: &DocCommentStyle, ) -> Result<ModificationResult>

Add a documentation comment to a target item using surgical editing

pub fn update_doc_comment_surgical( &mut self, target_type: &str, target_name: &str, doc_text: &str, style: &DocCommentStyle, ) -> Result<ModificationResult>

Update an existing documentation comment on a target item using surgical editing

pub fn remove_doc_comment_surgical( &mut self, target_type: &str, target_name: &str, ) -> Result<ModificationResult>

Remove a documentation comment from a target item using surgical editing