pub struct RustEditor { /* private fields */ }Implementations
Sourceimpl RustEditor
impl RustEditor
Sourceimpl RustEditor
impl RustEditor
Sourcepub fn add_doc_comment_surgical(
&mut self,
target_type: &str,
target_name: &str,
doc_text: &str,
style: &DocCommentStyle,
) -> Result<ModificationResult>
pub fn add_doc_comment_surgical( &mut self, target_type: &str, target_name: &str, doc_text: &str, style: &DocCommentStyle, ) -> Result<ModificationResult>
Add a documentation comment to a target item using surgical editing
Sourcepub fn update_doc_comment_surgical(
&mut self,
target_type: &str,
target_name: &str,
doc_text: &str,
style: &DocCommentStyle,
) -> Result<ModificationResult>
pub fn update_doc_comment_surgical( &mut self, target_type: &str, target_name: &str, doc_text: &str, style: &DocCommentStyle, ) -> Result<ModificationResult>
Update an existing documentation comment on a target item using surgical editing
Sourcepub fn remove_doc_comment_surgical(
&mut self,
target_type: &str,
target_name: &str,
) -> Result<ModificationResult>
pub fn remove_doc_comment_surgical( &mut self, target_type: &str, target_name: &str, ) -> Result<ModificationResult>
Remove a documentation comment from a target item using surgical editing