ModificationResult

Struct ModificationResult 

pub struct ModificationResult {
    pub changed: bool,
    pub modified_nodes: Vec<BackupNode>,
    pub unmatched_qualified_paths: Option<HashMap<String, usize>>,
}
Result of applying an operation

Fields

changed: boolmodified_nodes: Vec<BackupNode>unmatched_qualified_paths: Option<HashMap<String, usize>>

Unmatched qualified paths (only populated for struct literal operations with simple names) Maps fully qualified path to count of instances found but not matched