Module surgical
rs_hack
0.5.3
Module surgical
Module Items
Structs
Functions
In crate rs_
hack
rs_hack
Module
surgical
Structs

Replacement
Represents a single textual replacement in the source code.
Functions

apply_
surgical_
edits
Apply surgical edits to source code, preserving all formatting.